==> jc-1.4.0.tar.gz: javax/naming/directory/SearchResult.h <==
// public class javax.naming.directory.SearchResult

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a407f04d1ab17293 javax_naming_Binding
// @dep_class ab5d77113c6b669d javax_naming_NameClassPair
// @dep_class d51f4b9cc655a0f4 javax_naming_directory_SearchResult

// header file dependencies
// @dep_header javax_naming_Binding

#include "javax/naming/Binding.h"

#ifndef _JC_javax_naming_directory_SearchResult_H_
#define _JC_javax_naming_directory_SearchResult_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_naming_directory_Attributes$object;

// Typedefs
typedef struct _jc_javax_naming_directory_SearchResult$sub_refs	_jc_javax_naming_directory_SearchResult$sub_refs;
typedef struct _jc_javax_naming_directory_SearchResult$sub_nonrefs	_jc_javax_naming_directory_SearchResult$sub_nonrefs;
typedef struct _jc_javax_naming_directory_SearchResult$refs	_jc_javax_naming_directory_SearchResult$refs;
typedef struct _jc_javax_naming_directory_SearchResult$nonrefs	_jc_javax_naming_directory_SearchResult$nonrefs;
typedef struct _jc_javax_naming_directory_SearchResult$object	_jc_javax_naming_directory_SearchResult$object;

typedef const struct _jc_javax_naming_directory_SearchResult$vmethods	_jc_javax_naming_directory_SearchResult$vmethods;
typedef const struct _jc_javax_naming_directory_SearchResult$vtable	_jc_javax_naming_directory_SearchResult$vtable;
typedef const struct _jc_javax_naming_directory_SearchResult$vtype	_jc_javax_naming_directory_SearchResult$vtype;

// Constructors
extern void _jc_javax_naming_directory_SearchResult$method$_init$92279f8255aa59aa(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);
extern void _jc_javax_naming_directory_SearchResult$method$_init$b2a65505636a6a81(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, jboolean);
extern void _jc_javax_naming_directory_SearchResult$method$_init$9528272c21651d16(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);
extern void _jc_javax_naming_directory_SearchResult$method$_init$934d477fac9b35cc(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, jboolean);

// Virtual methods
extern struct _jc_object *_jc_javax_naming_directory_SearchResult$method$getAttributes$de01e608f1e92b33(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *);
extern void _jc_javax_naming_directory_SearchResult$method$setAttributes$500aa6eb30d444d4(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_javax_naming_directory_SearchResult$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_directory_SearchResult$method_info$getAttributes$de01e608f1e92b33;
extern _jc_method _jc_javax_naming_directory_SearchResult$method_info$setAttributes$500aa6eb30d444d4;
extern _jc_method _jc_javax_naming_directory_SearchResult$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_naming_directory_SearchResult$vmethods {
	struct _jc_object	*(*getAttributes$de01e608f1e92b33)(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *);
	void	(*setAttributes$500aa6eb30d444d4)(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *);
};

// Vtable
struct _jc_javax_naming_directory_SearchResult$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_NameClassPair$vmethods	javax_naming_NameClassPair;
	_jc_javax_naming_Binding$vmethods	javax_naming_Binding;
	_jc_javax_naming_directory_SearchResult$vmethods	javax_naming_directory_SearchResult;
};

// Vtype
struct _jc_javax_naming_directory_SearchResult$vtype {
	_jc_type			type;
	_jc_javax_naming_directory_SearchResult$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_directory_SearchResult$sub_refs {
	struct _jc_object	*attrs;
};

// Reference instance fields (object)
struct _jc_javax_naming_directory_SearchResult$refs {
    _jc_javax_naming_directory_SearchResult$sub_refs	javax_naming_directory_SearchResult;
    _jc_javax_naming_Binding$sub_refs	javax_naming_Binding;
    _jc_javax_naming_NameClassPair$sub_refs	javax_naming_NameClassPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_directory_SearchResult$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_directory_SearchResult$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_NameClassPair$sub_nonrefs	javax_naming_NameClassPair;
    _jc_javax_naming_Binding$sub_nonrefs	javax_naming_Binding;
    _jc_javax_naming_directory_SearchResult$sub_nonrefs	javax_naming_directory_SearchResult;
};

// Object instance structure
struct _jc_javax_naming_directory_SearchResult$object {
	_jc_javax_naming_directory_SearchResult$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_directory_SearchResult$vtype	*vtype;
	_jc_javax_naming_directory_SearchResult$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_directory_SearchResult$vtype _jc_javax_naming_directory_SearchResult$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_directory_SearchResult, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_directory_SearchResult$class_object;

#endif	/* _JC_javax_naming_directory_SearchResult_H_ */

==> jc-1.4.6.tar.gz: javax/naming/directory/SearchResult.h <==
// public class javax.naming.directory.SearchResult

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a407f04d1ab17293 javax_naming_Binding
// @dep_class ab5d77113c6b669d javax_naming_NameClassPair
// @dep_class d51f4b9cc655a0f4 javax_naming_directory_SearchResult

// header file dependencies
// @dep_header javax_naming_Binding

#include "javax/naming/Binding.h"

#ifndef _JC_javax_naming_directory_SearchResult_H_
#define _JC_javax_naming_directory_SearchResult_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_naming_directory_Attributes$object;

// Typedefs
typedef struct _jc_javax_naming_directory_SearchResult$sub_refs	_jc_javax_naming_directory_SearchResult$sub_refs;
typedef struct _jc_javax_naming_directory_SearchResult$sub_nonrefs	_jc_javax_naming_directory_SearchResult$sub_nonrefs;
typedef struct _jc_javax_naming_directory_SearchResult$refs	_jc_javax_naming_directory_SearchResult$refs;
typedef struct _jc_javax_naming_directory_SearchResult$nonrefs	_jc_javax_naming_directory_SearchResult$nonrefs;
typedef struct _jc_javax_naming_directory_SearchResult$object	_jc_javax_naming_directory_SearchResult$object;

typedef const struct _jc_javax_naming_directory_SearchResult$vmethods	_jc_javax_naming_directory_SearchResult$vmethods;
typedef const struct _jc_javax_naming_directory_SearchResult$vtable	_jc_javax_naming_directory_SearchResult$vtable;
typedef const struct _jc_javax_naming_directory_SearchResult$vtype	_jc_javax_naming_directory_SearchResult$vtype;

// Constructors
extern void _jc_javax_naming_directory_SearchResult$method$_init$92279f8255aa59aa(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_directory_SearchResult$method$_init$b2a65505636a6a81(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_javax_naming_directory_SearchResult$method$_init$9528272c21651d16(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_directory_SearchResult$method$_init$934d477fac9b35cc(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_naming_directory_SearchResult$method$getAttributes$de01e608f1e92b33(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_directory_SearchResult$method$setAttributes$500aa6eb30d444d4(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_naming_directory_SearchResult$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_directory_SearchResult$method_info$getAttributes$de01e608f1e92b33;
extern _jc_method _jc_javax_naming_directory_SearchResult$method_info$setAttributes$500aa6eb30d444d4;
extern _jc_method _jc_javax_naming_directory_SearchResult$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_naming_directory_SearchResult$vmethods {
	struct _jc_object	*(*getAttributes$de01e608f1e92b33)(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *) _JC_JCNI_ATTR;
	void	(*setAttributes$500aa6eb30d444d4)(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_naming_directory_SearchResult$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_directory_SearchResult$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_NameClassPair$vmethods	javax_naming_NameClassPair;
	_jc_javax_naming_Binding$vmethods	javax_naming_Binding;
	_jc_javax_naming_directory_SearchResult$vmethods	javax_naming_directory_SearchResult;
};

// Vtype
struct _jc_javax_naming_directory_SearchResult$vtype {
	_jc_type			type;
	_jc_javax_naming_directory_SearchResult$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_directory_SearchResult$sub_refs {
	struct _jc_object	*attrs;
};

// Reference instance fields (object)
struct _jc_javax_naming_directory_SearchResult$refs {
    _jc_javax_naming_directory_SearchResult$sub_refs	javax_naming_directory_SearchResult;
    _jc_javax_naming_Binding$sub_refs	javax_naming_Binding;
    _jc_javax_naming_NameClassPair$sub_refs	javax_naming_NameClassPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_directory_SearchResult$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_directory_SearchResult$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_NameClassPair$sub_nonrefs	javax_naming_NameClassPair;
    _jc_javax_naming_Binding$sub_nonrefs	javax_naming_Binding;
    _jc_javax_naming_directory_SearchResult$sub_nonrefs	javax_naming_directory_SearchResult;
};

// Object instance structure
struct _jc_javax_naming_directory_SearchResult$object {
	_jc_javax_naming_directory_SearchResult$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_directory_SearchResult$vtype	*vtype;
	_jc_javax_naming_directory_SearchResult$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_directory_SearchResult$vtype _jc_javax_naming_directory_SearchResult$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_directory_SearchResult, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_directory_SearchResult$class_object;

#endif	/* _JC_javax_naming_directory_SearchResult_H_ */
